noise.matrix-class: noise.matrix class

noise.matrix-classR Documentation

noise.matrix class

Description

This class object is generated by the bgNoise function. It can be read by soundSat.
Methods: show() and plot()

Value

A noise.matrix object

Slots

values

a list containing the values of BGN and POW. Indices are separated in individual data.frames by channel

timeBins

numeric vector containing the duration of each time bin

sampRate

single numeric string containing the audio's sampling rate

wl

single numeric string containing the spectrogram's window length

channel

single character string containing the channel or channels used to calculated the indices

See Also

bgNoise()


Ruido documentation built on April 18, 2026, 5:07 p.m.