plot-noise.matrix-ANY-method: Plot noise.matrix objects

plot,noise.matrix,ANY-methodR Documentation

Plot noise.matrix objects

Description

Plot noise.matrix objects

Usage

## S4 method for signature 'noise.matrix,ANY'
plot(
  x,
  channel = NULL,
  bin = 1,
  index = c("BGN", "POW"),
  nbreaks = 5,
  yunit = c("hz", "khz"),
  main = NULL,
  xlab = "dB",
  ylab = "Frequency",
  col = c("blue", "red"),
  type = "p",
  draw0 = TRUE,
  box = TRUE,
  axes = TRUE,
  annotate = TRUE,
  ...
)

Arguments

x

an noise.matrix object generated by bgNoise

channel

channel or channels to be ploted. By default, this set to x@channel, but can be changed to left or right if x@channel = stereo

bin

temporal bin to be plotted. Defaults to 1

index

a character vector of length 1 or 2 with indeces to be plotted. Available indices are: BGN and POW. Defaults to ⁠c("BGN", "POW)⁠

nbreaks

amount of breaks of the y axis. Defaults to 5

yunit

frequency unit to be used in plot. Available units are: "hz" and "khz". Defaults to "hz"

main

title for the plot. Set two strings if you are plotting and stereo noise.matrix. If set to NULL, default title will be ⁠left/right/mono channel⁠

xlab

label for the x-axis. Defaults to "dB"

ylab

label for the y-axis. Defaults to "Frequency"

col

plotting color for de indices. Defaults to c("blue","red")

type

desired plot type. For details see base::plot

draw0

if a stripped line should be drawn at 0. Defaults to TRUE

box

if a box should be drawn around the plot. Defaults to TRUE

axes

if axes should be drawn. Defaults to TRUE

annotate

if bin information should be added to the plot. Defaults to TRUE

...

further graphical parameters passed down to plot

Details

This is a method to quickly plot the results of bgNoise. This calls the helper function plotBGN, which is not meant to be used or seen by the user.


Ruido documentation built on April 18, 2026, 5:07 p.m.