View source: R/internalFunctions.R
| plotBGN | R Documentation |
noise.matrix objectsHelper function to plot noise.matrix objects
plotBGN(
x,
channel,
bin,
index,
nbreaks,
yunit,
main,
xlab,
ylab,
col,
type,
draw0,
box,
axes,
annotate,
...
)
x |
an |
channel |
channel or channels to be ploted. By default, this set to |
bin |
temporal bin to be plotted. Defaults to |
index |
a character vector of length 1 or 2 with indeces to be plotted. Available indices are: BGN and POW. Defaults to |
nbreaks |
amount of breaks of the y axis. Defaults to |
yunit |
frequency unit to be used in plot. Available units are: |
main |
title for the plot. Set two strings if you are plotting and stereo noise.matrix. If set to |
xlab |
label for the x-axis. Defaults to |
ylab |
label for the y-axis. Defaults to |
col |
plotting color for de indices. Defaults to |
type |
desired plot type. For details see base::plot |
draw0 |
if a stripped line should be drawn at 0. Defaults to |
box |
if a box should be drawn around the plot. Defaults to |
axes |
if axes should be drawn. Defaults to |
annotate |
if bin information should be added to the plot. Defaults to |
... |
further graphical parameters passed down to plot |
This is a helper function called by plot,Wave,missing-method. This is not intended to be seen or used by the user!
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.