| noise.matrix-class | R Documentation |
This class object is generated by the bgNoise function. It can be read by soundSat.
Methods: show() and plot()
A noise.matrix object
valuesa list containing the values of BGN and POW. Indices are separated in individual data.frames by channel
timeBinsnumeric vector containing the duration of each time bin
sampRatesingle numeric string containing the audio's sampling rate
wlsingle numeric string containing the spectrogram's window length
channelsingle character string containing the channel or channels used to calculated the indices
bgNoise()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.