| plot,noise.matrix,ANY-method | R Documentation |
Plot noise.matrix objects
## S4 method for signature 'noise.matrix,ANY'
plot(
x,
channel = NULL,
bin = 1,
index = c("BGN", "POW"),
nbreaks = 5,
yunit = c("hz", "khz"),
main = NULL,
xlab = "dB",
ylab = "Frequency",
col = c("blue", "red"),
type = "p",
draw0 = TRUE,
box = TRUE,
axes = TRUE,
annotate = TRUE,
...
)
x |
an |
channel |
channel or channels to be ploted. By default, this set to |
bin |
temporal bin to be plotted. Defaults to |
index |
a character vector of length 1 or 2 with indeces to be plotted. Available indices are: BGN and POW. Defaults to |
nbreaks |
amount of breaks of the y axis. Defaults to |
yunit |
frequency unit to be used in plot. Available units are: |
main |
title for the plot. Set two strings if you are plotting and stereo noise.matrix. If set to |
xlab |
label for the x-axis. Defaults to |
ylab |
label for the y-axis. Defaults to |
col |
plotting color for de indices. Defaults to |
type |
desired plot type. For details see base::plot |
draw0 |
if a stripped line should be drawn at 0. Defaults to |
box |
if a box should be drawn around the plot. Defaults to |
axes |
if axes should be drawn. Defaults to |
annotate |
if bin information should be added to the plot. Defaults to |
... |
further graphical parameters passed down to plot |
This is a method to quickly plot the results of bgNoise. This calls the helper function plotBGN, which is not meant to be used or seen by the user.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.